==> xxb.5.3.php71.zip: xxb/module/index/lang/zh-cn.php <==
<?php
/**
 * The zh-cn file of index module of XXB.
 *
 * @copyright   Copyright 2009-2020 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZOSL (https://zpl.pub/page/zoslv1.html)
 * @author      Chunsheng Wang <chunsheng@cnezsoft.com>
 * @package     index
 * @version     $Id: zh-cn.php 4029 2016-08-26 06:50:41Z liugang $
 * @link        https://xuanim.com
 */
$lang->index->common        = '首页';
$lang->index->index         = '首页';
$lang->index->dashboard     = '我的地盘';
$lang->index->dashboardAbbr = '我的';
$lang->index->about         = '关于';
$lang->index->profile       = '个人信息';
$lang->index->set           = '参数设置';
$lang->index->theme         = '更换主题';
$lang->index->superAdmin    = '后台管理';
$lang->index->showDesk      = '桌面';
$lang->index->customBlocks  = '编辑区块';
$lang->index->addBlock      = '添加区块';
$lang->index->refresh       = '更新';
$lang->index->hidden        = '隐藏';
$lang->index->status        = '状态监控';
$lang->index->statistics    = '系统统计';

$lang->index->fileSize      = '附件大小';
$lang->index->goUpdate      = '去更新';
$lang->index->countUsers    = '当前在线用户数';
$lang->index->setServer     = '服务器设置';
$lang->index->totalUsers    = '总用户数';
$lang->index->totalGroups   = '讨论组数';
$lang->index->totalMessages = '消息数量';
$lang->index->xxdStartDate  = 'XXD上次启动时间';
$lang->index->xxcNotice     = '喧喧发布新版本';
$lang->index->notInfo       = '没有权限无法查看首页内容。';

$lang->index->message = array();
$lang->index->message['total'] = '总消息数';
$lang->index->message['hour']  = '最近一小时消息数';
$lang->index->message['day']   = '最近一天消息数';

$lang->index->sizeType = array();
$lang->index->sizeType['K'] = 1024;
$lang->index->sizeType['M'] = 1024 * 1024;
$lang->index->sizeType['G'] = 1024 * 1024 * 1024;

==> xxb.9.1.1.php71.zip: xxb/module/index/lang/zh-cn.php <==
<?php
/**
 * The zh-cn file of index module of XXB.
 *
 * @copyright   Copyright 2009-2023 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd., www.zentao.net)
 * @license     ZOSL (https://zpl.pub/page/zoslv1.html)
 * @author      Chunsheng Wang <chunsheng@cnezsoft.com>
 * @package     index
 * @version     $Id: zh-cn.php 4029 2016-08-26 06:50:41Z liugang $
 * @link        https://xuanim.com
 */
$lang->index->common        = '首页';
$lang->index->index         = '首页';
$lang->index->dashboard     = '我的地盘';
$lang->index->dashboardAbbr = '我的';
$lang->index->about         = '关于';
$lang->index->profile       = '个人信息';
$lang->index->set           = '参数设置';
$lang->index->theme         = '更换主题';
$lang->index->superAdmin    = '后台管理';
$lang->index->showDesk      = '桌面';
$lang->index->customBlocks  = '编辑区块';
$lang->index->addBlock      = '添加区块';
$lang->index->refresh       = '更新';
$lang->index->hidden        = '隐藏';
$lang->index->status        = '状态监控';
$lang->index->statistics    = '系统统计';

$lang->index->fileSize      = '附件大小';
$lang->index->goUpdate      = '去更新';
$lang->index->countUsers    = '当前在线用户数';
$lang->index->setServer     = '服务器设置';
$lang->index->totalUsers    = '总用户数';
$lang->index->totalGroups   = '讨论组数';
$lang->index->totalMessages = '消息数量';
$lang->index->xxdStartDate  = 'XXD上次启动时间';
$lang->index->xxcNotice     = '喧喧发布新版本';
$lang->index->notInfo       = '没有权限无法查看首页内容。';

$lang->index->message = array();
$lang->index->message['total'] = '总消息数';
$lang->index->message['hour']  = '最近一小时消息数';
$lang->index->message['day']   = '最近一天消息数';

$lang->index->sizeType = array();
$lang->index->sizeType['K'] = 1024;
$lang->index->sizeType['M'] = 1024 * 1024;
$lang->index->sizeType['G'] = 1024 * 1024 * 1024;

$lang->upgradeBillboard = new stdclass();
$lang->upgradeBillboard->detachedConference = '您已启动新版会议，请及时更新客户端，也可联系用户进行手动升级。';
